@@ -1,22 +1,19 @@
+from pathlib import Path
 from typing import Union, Optional
 
-from RPA.Windows.keywords import (
-    ActionNotPossible,
-    keyword,
-    LibraryContext,
-)
+from RPA.Windows.keywords import ActionNotPossible, keyword, LibraryContext
 from RPA.Windows import utils
+from .locators import WindowsElement
 
 if utils.is_windows():
     import uiautomation as auto
-    from uiautomation.uiautomation import Control
 
 
 class ActionKeywords(LibraryContext):
     """Keywords for performing desktop actions"""
 
     @keyword(tags=["action", "mouse"])
-    def click(self, locator: Union[str, Control]):
+    def click(self, locator: Union[WindowsElement, str]):
         """Mouse click on element matching given locator.
 
         :param locator: string locator or Control element
@@ -32,7 +29,7 @@ class ActionKeywords(LibraryContext):
         return self._mouse_click(locator, "Click")
 
     @keyword(tags=["action", "mouse"])
-    def double_click(self, locator: Union[str, Control]):
+    def double_click(self, locator: Union[WindowsElement, str]):
         """Double mouse click on element matching given locator.
 
         :param locator: string locator or Control element
@@ -46,7 +43,7 @@ class ActionKeywords(LibraryContext):
         return self._mouse_click(locator, "DoubleClick")
 
     @keyword(tags=["action", "mouse"])
-    def right_click(self, locator: Union[str, Control]):
+    def right_click(self, locator: Union[WindowsElement, str]):
         """Right mouse click on element matching given locator.
 
         :param locator: string locator or Control element
@@ -60,7 +57,7 @@ class ActionKeywords(LibraryContext):
         return self._mouse_click(locator, "RightClick")
 
     @keyword(tags=["action", "mouse"])
-    def middle_click(self, locator: Union[str, Control]):
+    def middle_click(self, locator: Union[WindowsElement, str]):
         """Right mouse click on element matching given locator.
 
         :param locator: string locator or Control element
@@ -75,7 +72,7 @@ class ActionKeywords(LibraryContext):
 
     def _mouse_click(self, element, click_type):
         element = self._get_element_for_click(element)
-        if element.robocorp_click_offset:
+        if element.item.robocorp_click_offset:
             self._click_element_coordinates(element, click_type)
         else:
             self._click_element(element, click_type)
@@ -84,14 +81,14 @@ class ActionKeywords(LibraryContext):
     def _click_element_coordinates(self, element, click_type):
         callable_attribute = getattr(auto, click_type, None)
         if callable_attribute:
-            rect = element.BoundingRectangle
+            rect = element.item.BoundingRectangle
             offset_x, offset_y = [
-                int(v) for v in element.robocorp_click_offset.split(",")
+                int(v) for v in element.item.robocorp_click_offset.split(",")
             ]
             callable_attribute(
                 rect.xcenter() + offset_x,
                 rect.ycenter() + offset_y,
-                waitTime=self.ctx.timeout,
+                waitTime=self.ctx.wait_time,
             )
         else:
             raise ActionNotPossible(
@@ -99,9 +96,9 @@ class ActionKeywords(LibraryContext):
             )
 
     def _click_element(self, element, click_type):
-        attr = getattr(element, click_type, None)
+        attr = getattr(element.item, click_type, None)
         if attr and callable(attr):
-            attr(waitTime=self.ctx.timeout, simulateMove=self.ctx.simulate_move)
+            attr(waitTime=self.ctx.wait_time, simulateMove=self.ctx.simulate_move)
         else:
             raise ActionNotPossible(
                 "Element '%s' does not have '%s' attribute" % (element, click_type)
@@ -109,13 +106,13 @@ class ActionKeywords(LibraryContext):
 
     def _get_element_for_click(self, locator):
         element = self.ctx.get_element(locator)
-        if hasattr(element, "SetActive"):
-            element.SetActive()
-        element.MoveCursorToMyCenter(simulateMove=self.ctx.simulate_move)
+        if hasattr(element.item, "SetActive"):
+            element.item.SetActive()
+        element.item.MoveCursorToMyCenter(simulateMove=self.ctx.simulate_move)
         return element
 
     @keyword(tags=["action"])
-    def select(self, locator: Union[str, Control], value: str):
+    def select(self, locator: Union[WindowsElement, str], value: str):
         """Select value on Control element if action is supported.
 
         Will print warning if it is not possible to select on element.
@@ -130,8 +127,8 @@ class ActionKeywords(LibraryContext):
             Select  type:SelectControl   option2
         """
         element = self.ctx.get_element(locator)
-        if hasattr(element, "Select"):
-            element.Select(value)
+        if hasattr(element.item, "Select"):
+            element.item.Select(value)
         else:
             raise ActionNotPossible(
                 "Element '%s' does not have 'Select' attribute" % locator
@@ -140,7 +137,7 @@ class ActionKeywords(LibraryContext):
     @keyword(tags=["action"])
     def send_keys(
         self,
-        locator: Optional[Union[str, Control]] = None,
+        locator: Optional[Union[WindowsElement, str]] = None,
         keys: str = None,
         interval: float = 0.01,
         wait_time: float = None,
@@ -155,7 +152,7 @@ class ActionKeywords(LibraryContext):
         :param keys: the keys to send
         :param interval: time between sending keys, default 0.01 seconds
         :param wait_time: time to wait after sending keys, default is a
-         library timeout
+         library `wait_time`, see keyword ``Set Wait Time``
         :param send_enter: if True then {Enter} is sent at the end of the keys
 
         Example:
@@ -163,24 +160,24 @@ class ActionKeywords(LibraryContext):
         .. code-block:: robotframework
 
             Send Keys  desktop   {Ctrl}{F4}
-            Send Keys  None   {Ctrl}{F4}
+            Send Keys  keys={Ctrl}{F4}   # locator will be NONE, keys send to desktop
             Send Keys  id:input5  username   send_enter=True
-            ${control}=   Get Control   id:pass
-            Send Keys  ${control}  password   send_enter=True
+            ${element}=   Get Element   id:pass
+            Send Keys  ${element}  password   send_enter=True
         """
         element = self.ctx.get_element(locator)
-        keys_wait_time = wait_time or self.ctx.timeout
+        keys_wait_time = wait_time or self.ctx.wait_time
         if send_enter:
             keys += "{Enter}"
-        if hasattr(element, "SendKeys"):
-            element.SendKeys(keys, interval=interval, waitTime=keys_wait_time)
+        if hasattr(element.item, "SendKeys"):
+            element.item.SendKeys(keys, interval=interval, waitTime=keys_wait_time)
         else:
             raise ActionNotPossible(
                 "Element '%s' does not have 'SendKeys' attribute" % locator
             )
 
     @keyword
-    def get_text(self, locator: Union[str, Control]) -> str:
+    def get_text(self, locator: Union[WindowsElement, str]) -> str:
         """Get text from Control element defined by the locator.
 
         :param locator: string locator or Control element
@@ -192,14 +189,14 @@ class ActionKeywords(LibraryContext):
             ${date}=  Get Text   type:Edit name:'Date of birth'
         """
         element = self.ctx.get_element(locator)
-        if hasattr(element, "GetWindowText"):
-            return element.GetWindowText()
+        if hasattr(element.item, "GetWindowText"):
+            return element.item.GetWindowText()
         raise ActionNotPossible(
             "Element '%s' does not have 'GetWindowText' attribute" % locator
         )
 
     @keyword
-    def get_value(self, locator: Union[str, Control]) -> str:
+    def get_value(self, locator: Union[WindowsElement, str]) -> str:
         """Get value of the element defined by the locator.
 
         :param locator: string locator or Control element
@@ -211,52 +208,77 @@ class ActionKeywords(LibraryContext):
             ${value}=   Get Value   type:DataItem name:column1
         """
         element = self.ctx.get_element(locator)
-        if hasattr(element, "GetValuePattern"):
-            value_pattern = element.GetValuePattern()
+        if hasattr(element.item, "GetValuePattern"):
+            value_pattern = element.item.GetValuePattern()
             return value_pattern.Value
         raise ActionNotPossible(
             "Element '%s' does not have 'GetValuePattern' attribute" % locator,
         )
 
     @keyword(tags=["action"])
-    def set_value(self, locator: Union[str, Control], value: str) -> None:
+    def set_value(
+        self, locator: Union[WindowsElement, str], value: str, enter: bool = False
+    ) -> None:
         """Set value of the element defined by the locator.
 
         :param locator: string locator or Control element
         :param value: string value to set
+        :param enter: set True to send ENTER key to the element
 
         Example:
 
         .. code-block:: robotframework
 
             Set Value   type:DataItem name:column1   ab c  # Set value to "ab c"
+            # Press ENTER after setting the value
+            Set Value    type:Edit name:'File name:'    console.txt    True
         """
         element = self.ctx.get_element(locator)
-        if hasattr(element, "GetValuePattern"):
-            value_pattern = element.GetValuePattern()
+        if hasattr(element.item, "GetValuePattern"):
+            value_pattern = element.item.GetValuePattern()
             value_pattern.SetValue(value)
+            if enter:
+                self.send_keys(element, "{enter}")
         else:
             raise ActionNotPossible(
                 "Element '%s' does not have 'ValuePattern' attribute to set" % locator,
             )
 
     @keyword
-    def set_timeout(self, timeout: float) -> float:
-        """Set library timeout for action keywords.
+    def set_wait_time(self, wait_time: float) -> float:
+        """Set library wait time for action keywords.
 
-        This timeout is used as delay after each keyword performing mouse
-        or keyboard action.
+        The wait_time is spent after each keyword performing
+        mouse or keyboard action.
 
-        Returns value of the previous timeout value.
+        Library default wait_time is `0.5`
 
-        :param timeout: float value (in seconds), e.g. `0.1`
+        Returns value of the previous wait_time value.
+
+        :param wait_time: float value (in seconds), e.g. `0.1`
 
         Example:
 
         .. code-block:: robotframework
 
-            ${old_timeout}=  Set Timeout  0.2
+            ${old_wait_time}=  Set Wait Time  0.2
         """
-        old_value = self.ctx.timeout
-        self.ctx.timeout = timeout
+        old_value = self.ctx.wait_time
+        self.ctx.wait_time = wait_time
         return old_value
+
+    @keyword
+    def screenshot(self, locator: Union[WindowsElement, str], filename: str):
+        """Take a screenshot of the element defined by the locator.
+
+        :param locator: string locator or Control element
+        :param filename: image filename
+        """
+        filepath = Path(filename).resolve()
+        element = self.ctx.get_element(locator)
+        if hasattr(element.item, "CaptureToImage"):
+            element.item.CaptureToImage(str(filepath))
+        else:
+            raise ActionNotPossible(
+                "Element '%s' does not have 'CaptureToImage' attribute" % locator,
+            )
